@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
 # Copyright (c) 2021 Samsung Electronics.Co.Ltd.
@@ -91,7 +91,7 @@ def make_edges(nodes, sorted_info, dep_packages, cycle_edges, reduced_info):
                         edges.add(short_item)
         level = level + 1
 
-    for src_pkg, dst_pkgs in cycle_edges.items():
+    for src_pkg, dst_pkgs in list(cycle_edges.items()):
         for dst_pkg in dst_pkgs:
             if src_pkg in nodes and dst_pkg in nodes:
                 edges.add((src_pkg, dst_pkg, 'true'))
@@ -110,7 +110,7 @@ def make_full_edges(nodes, dep_packages, cycle_edges):
                 if dst_pkg in nodes:
                     edges.add((pkg, dst_pkg, 'false'))
 
-    for src_pkg, dst_pkgs in cycle_edges.items():
+    for src_pkg, dst_pkgs in list(cycle_edges.items()):
         for dst_pkg in dst_pkgs:
             if src_pkg in nodes and dst_pkg in nodes:
                 edges.add((src_pkg, dst_pkg, 'true'))
@@ -154,7 +154,7 @@ def topology_sort_package(nodes, dep_packages, in_edge_count, cycle_edges, reduc
 
     # compensate nodes.
     # if a node is in cycle_edges, insert it into the nodes.
-    for src, dst_pkgs in cycle_edges.items():
+    for src, dst_pkgs in list(cycle_edges.items()):
         if src not in nodes:
             continue
         for dst_pkg in dst_pkgs:
@@ -183,7 +183,7 @@ def find_main_package_name(sub_pkg_name, share_var):
 
     # If it is a main package, we cannot find it in sub_main_pkg.
     # In this case, just return the package name
-    if sub_pkg_name in share_var.main_sub_pkg.keys():
+    if sub_pkg_name in list(share_var.main_sub_pkg.keys()):
         return sub_pkg_name
 
     if not sub_pkg_name in share_var.sub_main_pkg:
@@ -200,8 +200,8 @@ def insert_sub_package(pkg_name, sub_pkg_name, share_var):
     share_var.main_sub_pkg[pkg_name].append(sub_pkg_name)
 
     if sub_pkg_name in share_var.sub_main_pkg:
-        print('Subpackage ' + sub_pkg_name + ' is related to one or more main ' + 'packages(' \
-              + share_var.sub_main_pkg[sub_pkg_name] + ',' + pkg_name + ')!\n')
+        print(('Subpackage ' + sub_pkg_name + ' is related to one or more main ' + 'packages(' \
+              + share_var.sub_main_pkg[sub_pkg_name] + ',' + pkg_name + ')!\n'))
     share_var.sub_main_pkg[sub_pkg_name] = pkg_name
 
     share_var.pkg_print_index[sub_pkg_name] = 0
@@ -240,7 +240,7 @@ def remove_cycle(main_pkg_edges, full_in_edge_count):
         for dst in dst_pkgs:
             if dst in path:
                 # cycle!
-                print("removing cycle (" + node + "->" + dst + ")")
+                print(("removing cycle (" + node + "->" + dst + ")"))
                 if node not in cycle_edges:
                     cycle_edges[node] = set()
                 cycle_edges[node].add(dst)
@@ -250,7 +250,7 @@ def remove_cycle(main_pkg_edges, full_in_edge_count):
                 visit(level + 1, dst)
         path.remove(node)
 
-    for pkg in main_pkg_edges.keys():
+    for pkg in list(main_pkg_edges.keys()):
         visit(0, pkg)
 
     return main_pkg_edges, cycle_edges, full_in_edge_count
@@ -398,7 +398,7 @@ def make_dep_graph(input_file_contents, dest_dir_name, package_name_ids):
     main_pkg_reverse_edges = {}
     full_in_reverse_edge_count = {}
     # generate main_pkg_edges using sub_pkg_edges
-    for src, dst_pkgs in share_var.sub_pkg_edges.items():
+    for src, dst_pkgs in list(share_var.sub_pkg_edges.items()):
         src_main = find_main_package_name(src, share_var)
         if src_main is None:
             continue
