@@ -23,7 +23,7 @@ import os
 import shutil
 import pwd
 import re
-import urlparse
+import urllib.parse
 import glob
 import gzip
 import requests
@@ -142,7 +142,7 @@ def prepare_repos_and_build_conf(args, arch, profile):
     if args.repositories:
         for repo in args.repositories:
             try:
-                if not urlparse.urlsplit(repo).scheme:
+                if not urllib.parse.urlsplit(repo).scheme:
                     if os.path.exists(repo):
                         repo = os.path.abspath(os.path.expanduser(repo))
                     else:
@@ -364,7 +364,7 @@ def get_local_archs(repos):
             root = ET.fromstring(fobj.read())
 
         xmlns = re.sub(r'metadata$', '', root.tag)
-        for elm in root.getiterator('%spackage' % xmlns):
+        for elm in root.iter('%spackage' % xmlns):
             arch = elm.find('%sarch' % xmlns).text
             if re.match(r'i[3-6]86', arch):
                 yield 'i586'
@@ -435,7 +435,7 @@ def create_autoconf(arch, snapshot, full_build):
 
     content += '[general]\nfallback_to_native = true\nprofile = ' + default + '\n'
     repos_map = {}
-    for k, v in obs_meta.iteritems():
+    for k, v in list(obs_meta.items()):
         ref_id = ref_meta.get(v)
         if ref_id == None:
             ref_id = 'latest'
@@ -472,7 +472,7 @@ def create_autoconf(arch, snapshot, full_build):
             content += '[repo.' + k + '_' + repo + '_pkgs]\n'
             content += 'url = ' + url + '/builddata/depends/' + v + '_' + repo + '_' + arch + '_revpkgdepends.xml\n'
 
-    for k, v in profile_meta.iteritems():
+    for k, v in list(profile_meta.items()):
         content += '[profile.' + k + ']\n'
         if full_build:
             v = v[:v.index('repo.' + k) - 1]
